@@ -98,7 +98,7 @@ def current_branch(show_tag_when_detached=False):
     return branch_name
 
 
-def checkout_branch(branch_name, create_from="master"):
+def checkout_branch(branch_name, create_from="main"):
     """Checkout the given Git branch"""
     # if already on selected branch, return true
     if current_branch(True) == branch_name:
@@ -147,9 +147,9 @@ def delete_branch(rm_branch):
 
     # If deleting the current branch, need to checkout a different branch first
     if this_branch == rm_branch:
-        # Use master branch, if possible
-        switch_to = 'master'
-        # If master is not an option
+        # Use main branch, if possible
+        switch_to = 'main'
+        # If main is not an option
         if rm_branch == switch_to or switch_to not in existing_branches:
             switch_to = None
             # Use first existing branch that is not the branch being deleted
@@ -534,7 +534,7 @@ def diff_branches(into_branch=None, from_branch=None):
     return changes
 
 
-def merged_branches(target_branch="master"):
+def merged_branches(target_branch="main"):
     """Get a list of all branches that have been merged into specified branch"""
     out.trace("merged_branches", [target_branch])
 
