@@ -108,7 +108,7 @@ class TestGit(unittest.TestCase):
 
         # List branches
         local_branches = git.list_branches()
-        self.assertTrue("master" in local_branches, "Local master branch missing")
+        self.assertTrue("main" in local_branches, "Local main branch missing")
         self.assertTrue(len(local_branches) == 2, "Did not list 2 local branches")
 
         # List remote branches
@@ -118,7 +118,7 @@ class TestGit(unittest.TestCase):
                 self.assertTrue(git.delete_remote_branch(test_branch), "Could not delete remote test branch")
                 remote_branches = git.list_remote_branches()
             num_remotes = len(remote_branches)
-            self.assertTrue("master" in remote_branches, "Remote master branch missing")
+            self.assertTrue("main" in remote_branches, "Remote main branch missing")
             self.assertTrue(num_remotes == 1, "Did not list 1 remote branch")
 
         # Create some new files
@@ -381,17 +381,17 @@ class TestGit(unittest.TestCase):
         if test_remote:
             # This branch was deleted, and then pulled back from remote
             self.assertTrue(git.delete_branch(new_branch), "Could not delete local test branch (3)")
-        self.assertTrue(len(git.list_branches()) == 1, "Only master branch should be left (local)")
+        self.assertTrue(len(git.list_branches()) == 1, "Only main branch should be left (local)")
 
         # Delete the test branches
         if test_remote:
             self.assertTrue(git.delete_remote_branch(test_branch), "Could not delete remote test branch (2)")
             self.assertTrue(git.delete_remote_branch(new_branch), "Could not delete remote test branch (3)")
-            self.assertTrue(len(git.list_remote_branches()) == 1, "Only master branch should be left (remote)")
+            self.assertTrue(len(git.list_remote_branches()) == 1, "Only main branch should be left (remote)")
 
         # Make sure last branch cannot be deleted (suppress the error)
         out.suppressConsoleOutput = True
-        self.assertFalse(git.delete_branch("master"), "Can not delete last existing branch")
+        self.assertFalse(git.delete_branch("main"), "Can not delete last existing branch")
         out.suppressConsoleOutput = False
 
         # Test function to run any git command
